<?php

namespace Bixo\Opportunity\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Opportunity\Actions\OfferAction;
use Bixo\Opportunity\Http\Requests\OfferActionRequest;
use Bixo\Opportunity\Http\Resources\OfferResource;
use Bixo\Opportunity\Models\Offer;

/**
 * Admin web controller class.
 */
class OfferActionController extends BaseController
{

    /**
     * Action controller function for offer.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(OfferActionRequest $request, Offer $offer, $action)
    {
        try {
            $request = $request->all();
            $offer = OfferAction::run($action, $offer, $request);

            $data = new OfferResource($offer);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('opportunity::offer.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('opportunity/offer/' . $offer->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('opportunity/offer/' . $offer->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
