<?php

namespace Bixo\Opportunity\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Opportunity\Actions\PreferanceAction;
use Bixo\Opportunity\Http\Requests\PreferanceActionRequest;
use Bixo\Opportunity\Http\Resources\PreferanceResource;
use Bixo\Opportunity\Models\Preferance;

/**
 * Admin web controller class.
 */
class PreferanceActionController extends BaseController
{

    /**
     * Action controller function for preferance.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(PreferanceActionRequest $request, Preferance $preferance, $action)
    {
        try {
            $request = $request->all();
            $preferance = PreferanceAction::run($action, $preferance, $request);

            $data = new PreferanceResource($preferance);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('opportunity::preferance.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('opportunity/preferance/' . $preferance->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('opportunity/preferance/' . $preferance->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
