<?php

namespace Bixo\Opportunity\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Bixo\Opportunity\Http\Requests\ViewingActionsRequest;
use Bixo\Opportunity\Actions\ViewingActions;

/**
 * Admin web controller class.
 */
class ViewingActionsController extends BaseController
{

    /**
     * Action controller function for viewing.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(ViewingActionsRequest $request, $action)
    {
        try {
            $viewing = ViewingActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('opportunity::viewing.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('opportunity/viewing/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('opportunity/viewing/' . $action))
                ->redirect();
        }
    }
}
