<?php

namespace Bixo\Opportunity\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Opportunity\Events\OfferAction as OfferActionEvent;
use Bixo\Opportunity\Notifications\OfferAction as OfferActionNotification;
use Litepie\Actions\Concerns\AsAction;

class OfferAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the OfferActionEvent.
     *
     * @param   OfferActionEvent  $event
     * @return mixed
     */
    public function handle(OfferActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $offer.
     *
     * @param   OfferActionEvent  $event
     * @return void
     */
    public function create(OfferActionEvent $event)
    {
        $client = $event->offer->client;
        Notification::send($client, new OfferActionNotification($event));
    }

    /**
     * Handle the OfferActionEvent as a listener.
     *
     * @param   OfferActionEvent  $event
     * @return mixed
     */
    public function asListener(OfferActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   OfferActionEvent  $event
     * @return bool
     */
    private function isAllowed(OfferActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
