<?php

namespace Bixo\Opportunity\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Opportunity\Events\OpportunityWorkflow as OpportunityWorkflowEvent;
use Bixo\Opportunity\Notifications\OpportunityWorkflow as OpportunityWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class OpportunityWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(OpportunityWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $opportunity is submitted.
     *
     * @param OpportunityWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(OpportunityWorkflowEvent $event)
    {
        $client = $event->opportunity->client;
        Notification::send($client, new OpportunityWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $opportunity is published.
     *
     * @param OpportunityWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(OpportunityWorkflowEvent $event)
    {
        $client = $event->opportunity->client;
        Notification::send($client, new OpportunityWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $opportunity is approved.
     *
     * @param OpportunityWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(OpportunityWorkflowEvent $event)
    {
        $client = $event->opportunity->client;
        Notification::send($client, new OpportunityWorkflowNotification($event));
    }

    /**
     * Handles the $opportunity workflow event as a listener.
     *
     * @param OpportunityWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(OpportunityWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
