<?php

namespace Bixo\Opportunity\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Opportunity\Events\PreferanceAction as PreferanceActionEvent;
use Bixo\Opportunity\Notifications\PreferanceAction as PreferanceActionNotification;
use Litepie\Actions\Concerns\AsAction;

class PreferanceAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the PreferanceActionEvent.
     *
     * @param   PreferanceActionEvent  $event
     * @return mixed
     */
    public function handle(PreferanceActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $preferance.
     *
     * @param   PreferanceActionEvent  $event
     * @return void
     */
    public function create(PreferanceActionEvent $event)
    {
        $client = $event->preferance->client;
        Notification::send($client, new PreferanceActionNotification($event));
    }

    /**
     * Handle the PreferanceActionEvent as a listener.
     *
     * @param   PreferanceActionEvent  $event
     * @return mixed
     */
    public function asListener(PreferanceActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   PreferanceActionEvent  $event
     * @return bool
     */
    private function isAllowed(PreferanceActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
