<?php

namespace Bixo\Opportunity\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Opportunity\Events\PreferanceWorkflow as PreferanceWorkflowEvent;
use Bixo\Opportunity\Notifications\PreferanceWorkflow as PreferanceWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class PreferanceWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(PreferanceWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $preferance is submitted.
     *
     * @param PreferanceWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(PreferanceWorkflowEvent $event)
    {
        $client = $event->preferance->client;
        Notification::send($client, new PreferanceWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $preferance is published.
     *
     * @param PreferanceWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(PreferanceWorkflowEvent $event)
    {
        $client = $event->preferance->client;
        Notification::send($client, new PreferanceWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $preferance is approved.
     *
     * @param PreferanceWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(PreferanceWorkflowEvent $event)
    {
        $client = $event->preferance->client;
        Notification::send($client, new PreferanceWorkflowNotification($event));
    }

    /**
     * Handles the $preferance workflow event as a listener.
     *
     * @param PreferanceWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(PreferanceWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
