<?php

namespace Bixo\Opportunity\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Opportunity\Events\ViewingAction as ViewingActionEvent;
use Bixo\Opportunity\Notifications\ViewingAction as ViewingActionNotification;
use Litepie\Actions\Concerns\AsAction;

class ViewingAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the ViewingActionEvent.
     *
     * @param   ViewingActionEvent  $event
     * @return mixed
     */
    public function handle(ViewingActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $viewing.
     *
     * @param   ViewingActionEvent  $event
     * @return void
     */
    public function create(ViewingActionEvent $event)
    {
        $client = $event->viewing->client;
        Notification::send($client, new ViewingActionNotification($event));
    }

    /**
     * Handle the ViewingActionEvent as a listener.
     *
     * @param   ViewingActionEvent  $event
     * @return mixed
     */
    public function asListener(ViewingActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   ViewingActionEvent  $event
     * @return bool
     */
    private function isAllowed(ViewingActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
