<?php

namespace Bixo\Opportunity\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Opportunity\Events\ViewingWorkflow as ViewingWorkflowEvent;
use Bixo\Opportunity\Notifications\ViewingWorkflow as ViewingWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class ViewingWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(ViewingWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $viewing is submitted.
     *
     * @param ViewingWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(ViewingWorkflowEvent $event)
    {
        $client = $event->viewing->client;
        Notification::send($client, new ViewingWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $viewing is published.
     *
     * @param ViewingWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(ViewingWorkflowEvent $event)
    {
        $client = $event->viewing->client;
        Notification::send($client, new ViewingWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $viewing is approved.
     *
     * @param ViewingWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(ViewingWorkflowEvent $event)
    {
        $client = $event->viewing->client;
        Notification::send($client, new ViewingWorkflowNotification($event));
    }

    /**
     * Handles the $viewing workflow event as a listener.
     *
     * @param ViewingWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(ViewingWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
