<?php
namespace Bixo\Opportunity\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Opportunity\Events\PreferanceAction as PreferanceActionEvent;
use Bixo\Opportunity\Models\Preferance;

class PreferanceAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $preferance;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param PreferanceActionEvent $preferance
     */
    public function __construct(PreferanceActionEvent $preferance)
    {
        $this->action = $event->action;
        $this->preferance = $preferance;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Preferance Approved - ' . config('app.name'))
            ->view('opportunity::preferance.email.action', ['data' => $this->preferance]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
