<?php
namespace Bixo\Opportunity\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Opportunity\Events\ViewingAction as ViewingActionEvent;
use Bixo\Opportunity\Models\Viewing;

class ViewingAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $viewing;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param ViewingActionEvent $viewing
     */
    public function __construct(ViewingActionEvent $viewing)
    {
        $this->action = $event->action;
        $this->viewing = $viewing;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Viewing Approved - ' . config('app.name'))
            ->view('opportunity::viewing.email.action', ['data' => $this->viewing]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
