<?php

namespace Bixo\Opportunity\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Opportunity\Models\Offer;

class OfferPolicy
{

    use OfferAction;
    use OfferWorkflow;

    /**
     * Determine if the given user can view the offer.
     *
     * @param Authenticatable $user
     * @param Offer $offer
     *
     * @return bool
     */
    public function view(Authenticatable $user, Offer $offer)
    {
        if ($authUser->canDo('opportunity.offer.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $offer->is_owner;
    }

    /**
     * Determine if the given user can create a offer.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('opportunity.offer.create');
    }

    /**
     * Determine if the given user can update the given offer.
     *
     * @param Authenticatable $user
     * @param Offer $offer
     *
     * @return bool
     */
    public function update(Authenticatable $user, Offer $offer)
    {
        if ($user->canDo('opportunity.offer.edit') && $user->isAdmin()) {
            return true;
        }

        return $offer->is_owner;
    }

    /**
     * Determine if the given user can delete the given offer.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Offer $offer)
    {
        return $offer->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
