<?php

namespace Bixo\Opportunity\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Opportunity\Models\Opportunity;

class OpportunityPolicy
{

    use OpportunityAction;
    use OpportunityWorkflow;

    /**
     * Determine if the given user can view the opportunity.
     *
     * @param Authenticatable $user
     * @param Opportunity $opportunity
     *
     * @return bool
     */
    public function view(Authenticatable $user, Opportunity $opportunity)
    {
        if ($authUser->canDo('opportunity.opportunity.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $opportunity->is_owner;
    }

    /**
     * Determine if the given user can create a opportunity.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('opportunity.opportunity.create');
    }

    /**
     * Determine if the given user can update the given opportunity.
     *
     * @param Authenticatable $user
     * @param Opportunity $opportunity
     *
     * @return bool
     */
    public function update(Authenticatable $user, Opportunity $opportunity)
    {
        if ($user->canDo('opportunity.opportunity.edit') && $user->isAdmin()) {
            return true;
        }

        return $opportunity->is_owner;
    }

    /**
     * Determine if the given user can delete the given opportunity.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Opportunity $opportunity)
    {
        return $opportunity->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
