<?php

namespace Bixo\Opportunity\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Opportunity\Models\Preferance;

class PreferancePolicy
{

    use PreferanceAction;
    use PreferanceWorkflow;

    /**
     * Determine if the given user can view the preferance.
     *
     * @param Authenticatable $user
     * @param Preferance $preferance
     *
     * @return bool
     */
    public function view(Authenticatable $user, Preferance $preferance)
    {
        if ($authUser->canDo('opportunity.preferance.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $preferance->is_owner;
    }

    /**
     * Determine if the given user can create a preferance.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('opportunity.preferance.create');
    }

    /**
     * Determine if the given user can update the given preferance.
     *
     * @param Authenticatable $user
     * @param Preferance $preferance
     *
     * @return bool
     */
    public function update(Authenticatable $user, Preferance $preferance)
    {
        if ($user->canDo('opportunity.preferance.edit') && $user->isAdmin()) {
            return true;
        }

        return $preferance->is_owner;
    }

    /**
     * Determine if the given user can delete the given preferance.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Preferance $preferance)
    {
        return $preferance->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
