<?php

namespace Bixo\Opportunity\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use Bixo\Opportunity\Models\Viewing;

class ViewingPolicy
{

    use ViewingAction;
    use ViewingWorkflow;

    /**
     * Determine if the given user can view the viewing.
     *
     * @param Authenticatable $user
     * @param Viewing $viewing
     *
     * @return bool
     */
    public function view(Authenticatable $user, Viewing $viewing)
    {
        if ($authUser->canDo('opportunity.viewing.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $viewing->is_owner;
    }

    /**
     * Determine if the given user can create a viewing.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('opportunity.viewing.create');
    }

    /**
     * Determine if the given user can update the given viewing.
     *
     * @param Authenticatable $user
     * @param Viewing $viewing
     *
     * @return bool
     */
    public function update(Authenticatable $user, Viewing $viewing)
    {
        if ($user->canDo('opportunity.viewing.edit') && $user->isAdmin()) {
            return true;
        }

        return $viewing->is_owner;
    }

    /**
     * Determine if the given user can delete the given viewing.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Viewing $viewing)
    {
        return $viewing->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
